"""Remove unused indexes in depends_on table

Revision ID: 3d0f03348c25
Revises: fcac91b2a3f1
Create Date: 2019-12-16 08:37:15.994395+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '3d0f03348c25'
down_revision = 'fcac91b2a3f1'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('depends_on_idx', table_name='depends_on')
    op.drop_index('depends_on_version_range_idx', table_name='depends_on')
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('depends_on_version_range_idx', 'depends_on', ['entity_id', 'version_id', 'version_range'], unique=False)
    op.create_index('depends_on_idx', 'depends_on', ['entity_id', 'version_id', 'version_range'], unique=False)
    # ### end Alembic commands ###



#!/usr/bin/env python3
# thoth-storages
# Copyright(C) 2019, 2020 Fridolin Pokorny, Francesco Murdaca
#
# This program is free software: you can redistribute it and / or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

"""Schema definition for inspection results."""

from voluptuous import Required, Optional
from voluptuous import Schema
from .result_schema import Datetime


# Metadata about specifications produced by inspections.
INSPECTION_SPECIFICATION_SCHEMA = Schema(
    {
        Required("base"): str,
        Optional("build"): dict,
        Optional("environment"): list,
        Optional("files"): list,
        Optional("identifier"): str,
        Optional("packages"): list,
        Optional("python"): dict,
        Optional("python_packages"): list,
        Optional("run"): dict,
        Optional("script"): str,
        Optional("update"): bool,
    }
)


# Metadata about job_log produced by inspections.
INSPECTION_JOB_LOG_SCHEMA = Schema(
    {
        Required("exit_code"): int,
        Required("hwinfo"): dict,
        Required("script_sha256"): str,
        Required("stderr"): str,
        Required("stdout"): dict,
        Required("usage"): dict,
        Required("os_release"): dict,
        Optional("runtime_environment"): dict,
    }
)


# Metadata about status produced by inspections.
INSPECTION_STATUS_SCHEMA = Schema(
    {
        Required("build"): dict,
        Required("job"): dict,
    }
)


# Metadata inspections.
INSPECTION_SCHEMA = Schema(
    {
        Required("specification"): INSPECTION_SPECIFICATION_SCHEMA,
        Required("created"): str,
        Required("build_log"): str,
        Required("job_log"): INSPECTION_JOB_LOG_SCHEMA,
        Required("inspection_id"): str,
        Required("status"): INSPECTION_STATUS_SCHEMA,
    }
)



"""Added kebechet installation table

Revision ID: 340d6e381d75
Revises: a7442899ef28
Create Date: 2020-05-18 18:28:55.710850+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '340d6e381d75'
down_revision = 'a7442899ef28'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_table('kebechet_github_installations',
    sa.Column('id', sa.Integer(), autoincrement=True, nullable=False),
    sa.Column('slug', sa.Text(), nullable=False),
    sa.Column('repo_name', sa.Text(), nullable=False),
    sa.Column('private', sa.Boolean(), nullable=False),
    sa.Column('installation_id', sa.Text(), nullable=False),
    sa.Column('is_active', sa.Boolean(), nullable=False),
    sa.PrimaryKeyConstraint('id'),
    sa.UniqueConstraint('slug')
    )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_table('kebechet_github_installations')
    # ### end Alembic commands ###



"""Added column aggregated_at to CVE

Revision ID: 9b210f8d5c24
Revises: 79e1d320db3d
Create Date: 2019-12-06 19:08:16.125613+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '9b210f8d5c24'
down_revision = '79e1d320db3d'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('cve', sa.Column('aggregated_at', sa.DateTime(), nullable=True))
    op.alter_column('cve', 'cve_id',
               existing_type=sa.VARCHAR(length=256),
               nullable=False)
    op.create_unique_constraint(None, 'cve', ['cve_id'])
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_constraint(None, 'cve', type_='unique')
    op.alter_column('cve', 'cve_id',
               existing_type=sa.VARCHAR(length=256),
               nullable=True)
    op.drop_column('cve', 'aggregated_at')
    # ### end Alembic commands ###



"""Add Requires-Python column to Python metadata

Revision ID: d808ef831749
Revises: 54d50b0eeb33
Create Date: 2019-10-22 10:30:43.326485+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = 'd808ef831749'
down_revision = '54d50b0eeb33'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.add_column('python_package_metadata', sa.Column('requires_python', sa.String(length=256), nullable=True))
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_column('python_package_metadata', 'requires_python')
    # ### end Alembic commands ###



"""Index platform

Revision ID: 7c261487d4d4
Revises: 9542eba46906
Create Date: 2020-06-08 07:41:56.496722+00:00

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '7c261487d4d4'
down_revision = '9542eba46906'
branch_labels = None
depends_on = None


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.create_index('depends_on_platform', 'depends_on', ['platform'], unique=False)
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.drop_index('depends_on_platform', table_name='depends_on')
    # ### end Alembic commands ###
